Coverage report

File | class |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src / sgn_gwframe / base.py | (no class) |  | 6 | 0 | 0 |  | 100.0%
src / sgn_gwframe / sinks / frame.py | FrameSink |  | 141 | 18 | 0 |  | 87.2%
src / sgn_gwframe / sinks / frame.py | (no class) |  | 37 | 0 | 2 |  | 100.0%
src / sgn_gwframe / sources / frame.py | CacheEntry |  | 6 | 0 | 0 |  | 100.0%
src / sgn_gwframe / sources / frame.py | FrameSource |  | 89 | 5 | 0 |  | 94.4%
src / sgn_gwframe / sources / frame.py | (no class) |  | 30 | 0 | 2 |  | 100.0%
src / sgn_gwframe / sources / framewatch.py | WorkerAction |  | 0 | 0 | 0 |  | 100.0%
src / sgn_gwframe / sources / framewatch.py | _FrameFileEventHandler |  | 17 | 6 | 0 |  | 64.7%
src / sgn_gwframe / sources / framewatch.py | FrameWatchSource |  | 113 | 8 | 0 |  | 92.9%
src / sgn_gwframe / sources / framewatch.py | (no class) |  | 91 | 0 | 5 |  | 100.0%
Total |  |  | 530 | 37 | 9 |  | 93.0%

No items found using the specified filter.